@@ -1,19 +1,15 @@
 package Class::XSAccessor;
-
-use 5.006;
-
+use 5.008;
 use strict;
 use warnings;
-
 use Carp qw/croak/;
+use Class::XSAccessor::Heavy;
+use XSLoader;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
-require XSLoader;
 XSLoader::load('Class::XSAccessor', $VERSION);
 
-require Class::XSAccessor::Heavy;
-
 sub _make_hash {
   my $ref = shift;
 
@@ -41,6 +37,7 @@ sub import {
   my $read_subs      = _make_hash($opts{getters} || {});
   my $set_subs       = _make_hash($opts{setters} || {});
   my $acc_subs       = _make_hash($opts{accessors} || {});
+  my $lvacc_subs     = _make_hash($opts{lvalue_accessors} || {});
   my $pred_subs      = _make_hash($opts{predicates} || {});
   my $test_subs      = _make_hash($opts{__tests__} || {});
   my $construct_subs = $opts{constructors} || [defined($opts{constructor}) ? $opts{constructor} : ()];
@@ -50,6 +47,7 @@ sub import {
   foreach my $subtype ( ["getter", $read_subs],
                         ["setter", $set_subs],
                         ["accessor", $acc_subs],
+                        ["lvalue_accessor", $lvacc_subs],
                         ["test", $test_subs],
                         ["pred_subs", $pred_subs] )
   {
@@ -79,10 +77,14 @@ sub _generate_method {
   $subname = "${caller_pkg}::$subname" if $subname !~ /::/;
 
   Class::XSAccessor::Heavy::check_sub_existence($subname) if not $opts->{replace};
+  no warnings 'redefine'; # don't warn about an explicitly requested redefine
 
   if ($type eq 'getter') {
     newxs_getter($subname, $hashkey);
   }
+  elsif ($type eq 'lvalue_accessor') {
+    newxs_lvalue_accessor($subname, $hashkey);
+  }
   elsif ($type eq 'setter') {
     newxs_setter($subname, $hashkey, $opts->{chained}||0);
   }
@@ -135,7 +137,10 @@ Class::XSAccessor - Generate fast XS accessors without runtime compilation
     predicates => {
       has_foo => 'foo',
       has_bar => 'bar',
-    }
+    },
+    lvalue_accessors => { # see below
+      baz => 'baz', # ...
+    },
     true  => [ 'is_token', 'is_whitespace' ],
     false => [ 'significant' ];
   
@@ -179,11 +184,12 @@ That means they can be called on objects and classes but will not
 clone objects entirely. Parameters to C<new()> are added to the
 object.
 
-The XS accessor methods are between 2 and 3 times faster than typical
+The XS accessor methods are between 3 and 4 times faster than typical
 pure-Perl accessors in some simple benchmarking.
 The lower factor applies to the potentially slightly obscure
 C<sub set_foo_pp {$_[0]-E<gt>{foo} = $_[1]}>, so if you usually
-write clear code, a factor of 2.5 speed-up is a good estimate.
+write clear code, a factor of 3.5 speed-up is a good estimate.
+If in doubt, do your own benchmarking!
 
 The method names may be fully qualified. The example in the synopsis could
 have been written as C<MyClass::get_foo> instead
@@ -235,6 +241,26 @@ in the same C<use Class::XSAccessor ...> statement.
 By default, the accessors are generated in the calling class. The
 the C<class> option allows the target class to be specified.
 
+=head1 LVALUES
+
+Support for lvalue accessors via the keyword C<lvalue_accessors>
+was added in version 1.08. At this point, B<THEY ARE CONSIDERED HIGHLY
+EXPERIMENTAL>. Furthermore, their performance hasn't been benchmarked
+yet.
+
+The following example demonstrates an lvalue accessor:
+
+  package Address;
+  use Class::XSAccessor
+    constructor => 'new',
+    lvalue_accessors => { zip_code => 'zip' };
+  
+  package main;
+  my $address = Address->new(zip => 2);
+  print $address->zip_code, "\n"; # prints 2
+  $address->zip_code = 76135; # <--- This is it!
+  print $address->zip_code, "\n"; # prints 76135
+
 =head1 CAVEATS
 
 Probably won't work for objects based on I<tied> hashes. But that's a strange thing to do anyway.
@@ -269,11 +295,11 @@ but it will be recycled when the same class, or a similar class, is loaded again
 
 Steffen Mueller E<lt>smueller@cpan.orgE<gt>
 
-Chocolateboy E<lt>chocolate@cpan.orgE<gt>
+chocolateboy E<lt>chocolate@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2009 by Steffen Mueller
+Copyright (C) 2008-2010 by Steffen Mueller
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8 or,
