@@ -1,11 +1,12 @@
-package Class::XSAccessor::Heavy;
+package # hide from PAUSE
+    Class::XSAccessor::Heavy;
 
-use 5.006;
+use 5.008;
 use strict;
 use warnings;
 use Carp;
 
-our $VERSION  = '1.07';
+our $VERSION  = '1.08';
 our @CARP_NOT = qw(
         Class::XSAccessor
         Class::XSAccessor::Array
@@ -61,11 +62,11 @@ L<Class::XSAccessor::Array>
 
 Steffen Mueller, E<lt>smueller@cpan.orgE<gt>
 
-Chocolateboy, E<lt>chocolate@cpan.orgE<gt>
+chocolateboy, E<lt>chocolate@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2009 by Steffen Mueller
+Copyright (C) 2008-2010 by Steffen Mueller
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8 or,
